<?php

return[
    'project_modules' => [
        'pages' => [
            'filemng' => [
                'label'        => 'Файл менеджер',
                'file'         => __DIR__ . '/../docs/filemng.md',
                'position'     => 70,
                'acl_resource' => 'filemanager',
                'acl_action'   => 'edit_file',
                'uri'          => 'filemanager/manage',
            ],
        ]
    ],
];
